@@ -1,13 +1,22 @@
 from json import dumps
 from json import loads
 
+from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_cant_reformat_json_error
+from je_api_testka.utils.exception.api_test_exceptions import APITesterJsonException
+
 
 def __process_json(json_string: str, **kwargs):
-    return dumps(loads(json_string), indent=4, sort_keys=True, **kwargs)
+    try:
+        return dumps(loads(json_string), indent=4, sort_keys=True, **kwargs)
+    except TypeError:
+        return dumps(json_string, indent=4, sort_keys=True, **kwargs)
 
 
 def reformat_json(json_string: str, **kwargs):
-    return __process_json(json_string, **kwargs)
+    try:
+        return __process_json(json_string, **kwargs)
+    except APITesterJsonException:
+        raise APITesterJsonException(api_test_cant_reformat_json_error)
 
 
 if __name__ == "__main__":
